@@ -311,8 +311,7 @@ imapx_update_message_info_flags (CamelMessageInfo *info,
                                  guint32 server_flags,
                                  const CamelNamedFlags *server_user_flags,
                                  guint32 permanent_flags,
-                                 CamelFolder *folder,
-                                 gboolean unsolicited)
+                                 CamelFolder *folder)
 {
 	gboolean changed = FALSE;
 	CamelIMAPXMessageInfo *xinfo = CAMEL_IMAPX_MESSAGE_INFO (info);
@@ -490,7 +489,8 @@ struct {
 	{ "X-GM-EXT-1", IMAPX_CAPABILITY_X_GM_EXT_1 },
 	{ "UTF8=ACCEPT", IMAPX_CAPABILITY_UTF8_ACCEPT },
 	{ "UTF8=ONLY", IMAPX_CAPABILITY_UTF8_ONLY },
-	{ "LOGINDISABLED", IMAPX_CAPABILITY_LOGINDISABLED }
+	{ "LOGINDISABLED", IMAPX_CAPABILITY_LOGINDISABLED },
+	{ "PREVIEW", IMAPX_CAPABILITY_PREVIEW }
 };
 
 static GMutex capa_htable_lock;         /* capabilities lookup table lock */
@@ -1788,6 +1788,8 @@ imapx_free_fetch (struct _fetch_info *finfo)
 		g_bytes_unref (finfo->text);
 	if (finfo->header)
 		g_bytes_unref (finfo->header);
+	if (finfo->preview)
+		g_bytes_unref (finfo->preview);
 	if (finfo->cinfo)
 		camel_message_content_info_free (finfo->cinfo);
 	camel_named_flags_free (finfo->user_flags);
@@ -2012,6 +2014,24 @@ imapx_parse_fetch_modseq (CamelIMAPXInputStream *stream,
 	return (finfo->modseq > 0);
 }
 
+static gboolean
+imapx_parse_fetch_preview (CamelIMAPXInputStream *stream,
+			   struct _fetch_info *finfo,
+			   GCancellable *cancellable,
+			   GError **error)
+{
+	gboolean success;
+
+	success = camel_imapx_input_stream_nstring_bytes (
+		stream, &finfo->preview, FALSE, cancellable, error);
+
+	/* the preview can be NIL */
+	if (success && finfo->preview)
+		finfo->got |= FETCH_PREVIEW;
+
+	return success;
+}
+
 static gboolean
 imapx_parse_fetch_rfc822_header (CamelIMAPXInputStream *stream,
                                  struct _fetch_info *finfo,
@@ -2173,6 +2193,11 @@ imapx_parse_fetch (CamelIMAPXInputStream *stream,
 					stream, finfo, cancellable, error);
 				break;
 
+			case IMAPX_PREVIEW:
+				success = imapx_parse_fetch_preview (
+					stream, finfo, cancellable, error);
+				break;
+
 			case IMAPX_RFC822_HEADER:
 				success = imapx_parse_fetch_rfc822_header (
 					stream, finfo, cancellable, error);
@@ -2599,8 +2624,6 @@ imapx_parse_status (CamelIMAPXInputStream *stream,
 		goto fail;
 
 	if (tok == '[') {
-		gboolean success;
-
 		success = camel_imapx_input_stream_atom (
 			stream, &token, &len, cancellable, error);
 
@@ -3364,6 +3387,7 @@ imapx_verify_tokens_tab (void)
 		item (IMAPX_PARSE),
 		item (IMAPX_PERMANENTFLAGS),
 		item (IMAPX_PREAUTH),
+		item (IMAPX_PREVIEW),
 		{ IMAPX_READ_ONLY, "READ-ONLY" },
 		{ IMAPX_READ_WRITE, "READ-WRITE" },
 		item (IMAPX_RECENT),
