@@ -44,7 +44,7 @@ test_cursor_sexp_calculate_position (TCUCursorFixture *fixture,
 
 	/* Ensure we moved to the right contact */
 	node = g_slist_last (results);
-	g_assert (node);
+	g_assert_true (node);
 	data = node->data;
 	g_assert_cmpstr (data->uid, ==, "sorted-16");
 	g_slist_free_full (results, e_book_cache_search_data_free);
@@ -108,7 +108,7 @@ test_cursor_sexp_and_step (TCUCursorFixture *fixture,
 
 	/* Ensure we moved to the right contact */
 	node = g_slist_last (results);
-	g_assert (node);
+	g_assert_true (node);
 	data = node->data;
 	g_assert_cmpstr (data->uid, ==, "sorted-8");
 	g_slist_free_full (results, e_book_cache_search_data_free);
@@ -124,7 +124,7 @@ test_cursor_sexp_and_step (TCUCursorFixture *fixture,
 
 	/* Ensure we moved to the right contact */
 	node = g_slist_last (results);
-	g_assert (node);
+	g_assert_true (node);
 	data = node->data;
 	g_assert_cmpstr (data->uid, ==, "sorted-12");
 	g_slist_free_full (results, e_book_cache_search_data_free);
@@ -140,6 +140,9 @@ main (gint argc,
 	g_type_init ();
 #endif
 	g_test_init (&argc, &argv, NULL);
+	g_test_bug_base ("https://gitlab.gnome.org/GNOME/evolution-data-server/");
+
+	tcu_read_args (argc, argv);
 
 	g_test_add (
 		"/EBookCacheCursor/SetSexp/CalculatePosition", TCUCursorFixture, &book_closure,
@@ -152,5 +155,5 @@ main (gint argc,
 		test_cursor_sexp_and_step,
 		tcu_cursor_fixture_teardown);
 
-	return e_test_server_utils_run_full (0);
+	return e_test_server_utils_run_full (argc, argv, 0);
 }
